@@ -19,6 +19,7 @@ import qrules
 import sympy as sp
 from sympy.printing.numpy import NumPyPrinter
 
+from ampform.io import aslatex
 from ampform.kinematics import FourMomentumSymbol, _ArraySize
 from ampform.sympy import NumPyPrintable
 from ampform.sympy._array_expressions import ArrayMultiplication
@@ -156,7 +157,7 @@ def extend_BoostZMatrix() -> None:
 
 
 def extend_BreakupMomentumSquared() -> None:
-    from ampform.dynamics import BreakupMomentumSquared
+    from ampform.dynamics.phasespace import BreakupMomentumSquared
 
     s, m_a, m_b = sp.symbols("s, m_a, m_b")
     expr = BreakupMomentumSquared(s, m_a, m_b)
@@ -171,12 +172,49 @@ def extend_ComplexSqrt() -> None:
     _append_to_docstring(
         ComplexSqrt,
         Rf"""
-    .. math:: {sp.latex(expr)} = {sp.latex(expr.evaluate())}
+    .. math:: {sp.latex(expr)} = {sp.latex(expr.get_definition())}
         :label: ComplexSqrt
     """,
     )
 
 
+def extend_compute_third_mandelstam() -> None:
+    from ampform.kinematics.phasespace import compute_third_mandelstam
+
+    m0, m1, m2, m3 = sp.symbols("m:4")
+    s1, s2 = sp.symbols("sigma1 sigma2")
+    expr = compute_third_mandelstam(s1, s2, m0, m1, m2, m3)
+    _append_to_docstring(
+        compute_third_mandelstam,
+        Rf"""
+
+    .. math:: \sigma_3 = {sp.latex(expr)}
+        :label: compute_third_mandelstam
+
+    Note that this expression is symmetric in :math:`\sigma_{{1,2,3}}`.
+    """,
+    )
+
+
+def extend_EqualMassPhaseSpaceFactor() -> None:
+    from ampform.dynamics.phasespace import (
+        EqualMassPhaseSpaceFactor,
+        PhaseSpaceFactorAbs,
+    )
+
+    s, m_a, m_b = sp.symbols(R"s, m_a, m_b")
+    expr = EqualMassPhaseSpaceFactor(s, m_a, m_b)
+    _append_latex_doit_definition(expr)
+    rho_hat = PhaseSpaceFactorAbs(s, m_a, m_b)
+    _append_to_docstring(
+        EqualMassPhaseSpaceFactor,
+        f"""
+    with :math:`{sp.latex(rho_hat)}` defined by `.PhaseSpaceFactorAbs`
+    :eq:`PhaseSpaceFactorAbs`.
+    """,
+    )
+
+
 def extend_EnergyDependentWidth() -> None:
     from ampform.dynamics import EnergyDependentWidth
 
@@ -240,6 +278,51 @@ def extend_EuclideanNorm() -> None:
     _append_code_rendering(expr)
 
 
+def extend_formulate_form_factor() -> None:
+    from ampform.dynamics import formulate_form_factor
+
+    s, m_a, m_b, L, d = sp.symbols("s m_a m_b L d")
+    form_factor = formulate_form_factor(
+        s, m_a, m_b, angular_momentum=L, meson_radius=d
+    )
+    _append_to_docstring(
+        formulate_form_factor,
+        f"""
+    .. math:: {sp.latex(form_factor)}
+        :label: formulate_form_factor
+    """,
+    )
+
+
+def extend_Kallen() -> None:
+    from ampform.kinematics.phasespace import Kallen
+
+    x, y, z = sp.symbols("x:z")
+    expr = Kallen(x, y, z)
+    _append_latex_doit_definition(expr)
+    _append_to_docstring(
+        Kallen,
+        """
+    .. seealso:: `.BreakupMomentumSquared`
+    """,
+    )
+
+
+def extend_Kibble() -> None:
+    from ampform.kinematics.phasespace import Kibble
+
+    m0, m1, m2, m3 = sp.symbols("m:4")
+    s1, s2, s3 = sp.symbols("sigma1:4")
+    expr = Kibble(s1, s2, s3, m0, m1, m2, m3)
+    _append_latex_doit_definition(expr)
+    _append_to_docstring(
+        Kibble,
+        R"""
+    with :math:`\lambda` defined by :eq:`Kallen`.
+    """,
+    )
+
+
 def extend_InvariantMass() -> None:
     from ampform.kinematics import InvariantMass
 
@@ -248,8 +331,26 @@ def extend_InvariantMass() -> None:
     _append_latex_doit_definition(expr)
 
 
+def extend_is_within_phasespace() -> None:
+    from ampform.kinematics.phasespace import is_within_phasespace
+
+    m0, m1, m2, m3 = sp.symbols("m:4")
+    s1, s2 = sp.symbols("sigma1 sigma2")
+    expr = is_within_phasespace(s1, s2, m0, m1, m2, m3)
+    _append_to_docstring(
+        is_within_phasespace,
+        Rf"""
+
+    .. math:: {sp.latex(expr)}
+        :label: is_within_phasespace
+
+    with :math:`\phi` defined by :eq:`Kibble`.
+    """,
+    )
+
+
 def extend_PhaseSpaceFactor() -> None:
-    from ampform.dynamics import PhaseSpaceFactor
+    from ampform.dynamics.phasespace import PhaseSpaceFactor
 
     s, m_a, m_b = sp.symbols("s, m_a, m_b")
     expr = PhaseSpaceFactor(s, m_a, m_b)
@@ -263,7 +364,7 @@ def extend_PhaseSpaceFactor() -> None:
 
 
 def extend_PhaseSpaceFactorAbs() -> None:
-    from ampform.dynamics import PhaseSpaceFactorAbs
+    from ampform.dynamics.phasespace import PhaseSpaceFactorAbs
 
     s, m_a, m_b = sp.symbols("s, m_a, m_b")
     expr = PhaseSpaceFactorAbs(s, m_a, m_b)
@@ -276,24 +377,8 @@ def extend_PhaseSpaceFactorAbs() -> None:
     )
 
 
-def extend_PhaseSpaceFactorAnalytic() -> None:
-    from ampform.dynamics import PhaseSpaceFactorAbs, PhaseSpaceFactorAnalytic
-
-    s, m_a, m_b = sp.symbols(R"s, m_a, m_b")
-    expr = PhaseSpaceFactorAnalytic(s, m_a, m_b)
-    _append_latex_doit_definition(expr)
-    rho_hat = PhaseSpaceFactorAbs(s, m_a, m_b)
-    _append_to_docstring(
-        PhaseSpaceFactorAnalytic,
-        f"""
-    with :math:`{sp.latex(rho_hat)}` defined by `.PhaseSpaceFactorAbs`
-    :eq:`PhaseSpaceFactorAbs`.
-    """,
-    )
-
-
 def extend_PhaseSpaceFactorComplex() -> None:
-    from ampform.dynamics import PhaseSpaceFactorComplex
+    from ampform.dynamics.phasespace import PhaseSpaceFactorComplex
 
     s, m_a, m_b = sp.symbols("s, m_a, m_b")
     expr = PhaseSpaceFactorComplex(s, m_a, m_b)
@@ -306,6 +391,14 @@ def extend_PhaseSpaceFactorComplex() -> None:
     )
 
 
+def extend_PhaseSpaceFactorSWave() -> None:
+    from ampform.dynamics.phasespace import PhaseSpaceFactorSWave
+
+    s, m_a, m_b = sp.symbols("s m_a m_b")
+    expr = PhaseSpaceFactorSWave(s, m_a, m_b)
+    _append_latex_doit_definition(expr, full_width=True)
+
+
 def extend_Phi() -> None:
     from ampform.kinematics import Phi
 
@@ -389,6 +482,26 @@ def extend_ThreeMomentum() -> None:
     _append_code_rendering(expr)
 
 
+def extend_chew_mandelstam_s_wave() -> None:
+    from ampform.dynamics.phasespace import chew_mandelstam_s_wave
+
+    s, m_a, m_b = sp.symbols("s m_a m_b")
+    expr = chew_mandelstam_s_wave(s, m_a, m_b)
+    _append_to_docstring(
+        chew_mandelstam_s_wave,
+        Rf"""
+
+    .. math:: {sp.latex(expr)}
+        :class: full-width
+        :label: chew_mandelstam_s_wave
+
+    with :math:`q^2(s)` defined as :eq:`BreakupMomentumSquared`.
+
+    .. seealso:: :doc:`compwa-org:report/003`
+    """,
+    )
+
+
 def extend_formulate_clebsch_gordan_coefficients() -> None:
     from ampform.helicity import formulate_clebsch_gordan_coefficients
 
@@ -582,9 +695,7 @@ def _append_latex_doit_definition(
 
 
 def _create_latex_doit_definition(expr: sp.Expr, deep: bool = False) -> str:
-    latex = sp.multiline_latex(
-        expr, expr.doit(deep=deep), environment="eqnarray"
-    )
+    latex = aslatex({expr: expr.doit(deep=deep)})
     return textwrap.indent(latex, prefix=8 * " ")
 
 
