@@ -85,6 +85,7 @@ subprocess.call(
             "sphinx-apidoc",
             f"../src/{PACKAGE}/",
             f"../src/{PACKAGE}/version.py",
+            f"../src/{PACKAGE}/io/latex.py",
             "-o api/",
             "--force",
             "--no-toc",
@@ -211,7 +212,6 @@ html_theme_options = {
     },
     "show_navbar_depth": 2,
     "show_toc_level": 2,
-    "theme_dev_mode": True,
 }
 html_title = "AmpForm"
 panels_add_bootstrap_css = False  # remove panels css to get wider main content
@@ -332,29 +332,15 @@ linkcheck_ignore = [
 ]
 
 # Settings for myst_nb
-execution_timeout = -1
+nb_execution_timeout = -1
 nb_output_stderr = "remove"
-nb_render_priority = {
-    "html": (
-        "application/vnd.jupyter.widget-view+json",
-        "application/javascript",
-        "text/html",
-        "image/svg+xml",
-        "image/png",
-        "image/jpeg",
-        "text/markdown",
-        "text/latex",
-        "text/plain",
-    )
-}
-nb_render_priority["doctest"] = nb_render_priority["html"]
 
-jupyter_execute_notebooks = "off"
+nb_execution_mode = "off"
 EXECUTE_NB = False
 if "EXECUTE_NB" in os.environ:
     print("\033[93;1mWill run Jupyter notebooks!\033[0m")
     EXECUTE_NB = True
-    jupyter_execute_notebooks = "force"
+    nb_execution_mode = "cache"
 
 # Settings for myst-parser
 myst_enable_extensions = [
