@@ -10,12 +10,11 @@ from attrs.validators import instance_of
 from qrules.particle import Particle
 
 from . import (
-    BlattWeisskopfSquared,
-    BreakupMomentumSquared,
     EnergyDependentWidth,
+    EqualMassPhaseSpaceFactor,
     PhaseSpaceFactor,
-    PhaseSpaceFactorAnalytic,
     PhaseSpaceFactorProtocol,
+    formulate_form_factor,
     relativistic_breit_wigner,
 )
 
@@ -69,7 +68,6 @@ class ResonanceDynamicsBuilder(Protocol):
         self, resonance: Particle, variable_pool: TwoBodyKinematicVariableSet
     ) -> BuilderReturnType:
         """Formulate a dynamics `~sympy.core.expr.Expr` for this resonance."""
-        ...
 
 
 def create_non_dynamic(
@@ -84,28 +82,24 @@ def create_non_dynamic_with_ff(
 ) -> BuilderReturnType:
     """Generate (only) a Blatt-Weisskopf form factor for a two-body decay.
 
-    Returns the `~sympy.functions.elementary.miscellaneous.sqrt` of a
-    `.BlattWeisskopfSquared`.
+    See also :func:`.formulate_form_factor`.
     """
-    angular_momentum = variable_pool.angular_momentum
-    if angular_momentum is None:
+    if variable_pool.angular_momentum is None:
         raise ValueError(
             "Angular momentum is not defined but is required in the form"
             " factor!"
         )
-    q_squared = BreakupMomentumSquared(
+    res_identifier = resonance.latex if resonance.latex else resonance.name
+    meson_radius = sp.Symbol(f"d_{{{res_identifier}}}", positive=True)
+    form_factor = formulate_form_factor(
         s=variable_pool.incoming_state_mass**2,
         m_a=variable_pool.outgoing_state_mass1,
         m_b=variable_pool.outgoing_state_mass2,
-    )
-    res_identifier = resonance.latex if resonance.latex else resonance.name
-    meson_radius = sp.Symbol(f"d_{{{res_identifier}}}")
-    form_factor_squared = BlattWeisskopfSquared(
-        angular_momentum,
-        z=q_squared * meson_radius**2,
+        angular_momentum=variable_pool.angular_momentum,
+        meson_radius=meson_radius,
     )
     return (
-        sp.sqrt(form_factor_squared),
+        form_factor,
         {meson_radius: 1},
     )
 
@@ -119,11 +113,10 @@ class RelativisticBreitWignerBuilder:
 
     Args:
         form_factor: Formulate a relativistic Breit-Wigner function multiplied
-            by a Blatt-Weisskopf form factor, see Equation
-            :eq:`BlattWeisskopfSquared`.
+            by a Blatt-Weisskopf form factor (`.BlattWeisskopfSquared`), like
+            in Equation (50.26) on :pdg-review:`2021; Resonances; p.9`.
         energy_dependent_width: Use an `.EnergyDependentWidth` in the
-            denominator of the Breit-Wigner. See
-            :pdg-review:`2020; Resonances; p.6`, Equation (49.21).
+            denominator of the Breit-Wigner.
         phsp_factor: A class that complies with the
             `.PhaseSpaceFactorProtocol` that is used in the energy-dependent
             width. Defaults to `.PhaseSpaceFactor`.
@@ -166,9 +159,9 @@ class RelativisticBreitWignerBuilder:
         resonance: Particle, variable_pool: TwoBodyKinematicVariableSet
     ) -> BuilderReturnType:
         inv_mass = variable_pool.incoming_state_mass
-        res_identifier = resonance.latex if resonance.latex else resonance.name
-        res_mass = sp.Symbol(f"m_{{{res_identifier}}}")
-        res_width = sp.Symbol(Rf"\Gamma_{{{res_identifier}}}")
+        identifier = resonance.latex if resonance.latex else resonance.name
+        res_mass = sp.Symbol(f"m_{{{identifier}}}", nonnegative=True)
+        res_width = sp.Symbol(Rf"\Gamma_{{{identifier}}}", nonnegative=True)
         expression = relativistic_breit_wigner(
             s=inv_mass**2,
             mass0=res_mass,
@@ -226,33 +219,27 @@ class RelativisticBreitWignerBuilder:
             )
 
         inv_mass = variable_pool.incoming_state_mass
-        angular_momentum = variable_pool.angular_momentum
-        res_mass, res_width, meson_radius = self.__create_symbols(resonance)
-
-        q_squared = BreakupMomentumSquared(
+        _, __, meson_radius = self.__create_symbols(resonance)
+        form_factor = formulate_form_factor(
             s=inv_mass**2,
             m_a=variable_pool.outgoing_state_mass1,
             m_b=variable_pool.outgoing_state_mass2,
+            angular_momentum=variable_pool.angular_momentum,
+            meson_radius=meson_radius,
         )
-        ff_squared = BlattWeisskopfSquared(
-            angular_momentum, z=q_squared * meson_radius**2
-        )
-        form_factor = sp.sqrt(ff_squared)
         parameter_defaults = {
-            res_mass: resonance.mass,
-            res_width: resonance.width,
             meson_radius: 1,
         }
-        return form_factor, parameter_defaults
+        return form_factor, parameter_defaults  # type: ignore[return-value]
 
     @staticmethod
     def __create_symbols(
         resonance: Particle,
     ) -> tuple[sp.Symbol, sp.Symbol, sp.Symbol]:
-        res_identifier = resonance.latex if resonance.latex else resonance.name
-        res_mass = sp.Symbol(f"m_{{{res_identifier}}}")
-        res_width = sp.Symbol(Rf"\Gamma_{{{res_identifier}}}")
-        meson_radius = sp.Symbol(f"d_{{{res_identifier}}}")
+        identifier = resonance.latex if resonance.latex else resonance.name
+        res_mass = sp.Symbol(f"m_{{{identifier}}}", nonnegative=True)
+        res_width = sp.Symbol(Rf"\Gamma_{{{identifier}}}", nonnegative=True)
+        meson_radius = sp.Symbol(f"d_{{{identifier}}}", positive=True)
         return res_mass, res_width, meson_radius
 
 
@@ -281,14 +268,14 @@ form factor and a 'normal' `.PhaseSpaceFactor`.
 create_analytic_breit_wigner = RelativisticBreitWignerBuilder(
     energy_dependent_width=True,
     form_factor=True,
-    phsp_factor=PhaseSpaceFactorAnalytic,
+    phsp_factor=EqualMassPhaseSpaceFactor,
 ).__call__
 """
 Create a `.relativistic_breit_wigner_with_ff` with analytic continuation.
 
 This is a convenience function for a `RelativisticBreitWignerBuilder` _with_
 form factor and a 'analytic' phase space factor (see
-`.PhaseSpaceFactorAnalytic`).
+`.EqualMassPhaseSpaceFactor`).
 
 .. seealso:: :doc:`/usage/dynamics/analytic-continuation`.
 """
