@@ -1,6 +1,6 @@
 r"""Experimental, symbol :math:`\boldsymbol{K}`-matrix implementations.
 
-See :doc:`/usage/dynamics/k-matrix`.
+.. seealso:: :doc:`/usage/dynamics/k-matrix`.
 
 This module is an implementation of :doc:`compwa-org:report/005`,
 :doc:`compwa-org:report/009`, and :doc:`compwa-org:report/010`. It works with
@@ -16,11 +16,10 @@ from abc import ABC, abstractmethod
 import sympy as sp
 
 from ampform.dynamics import (
-    BlattWeisskopfSquared,
-    BreakupMomentumSquared,
     EnergyDependentWidth,
     PhaseSpaceFactor,
     PhaseSpaceFactorProtocol,
+    formulate_form_factor,
 )
 from ampform.sympy import create_symbol_matrix
 
@@ -55,7 +54,7 @@ class RelativisticKMatrix(TMatrix):
     def formulate(
         cls, n_channels, n_poles, parametrize: bool = True, **kwargs
     ) -> sp.MutableDenseMatrix:
-        r"""Implementation of :eq:`T-hat in terms of K-hat`.
+        r"""Implementation of :eq:`T-hat-in-terms-of-K-hat`.
 
         Args:
             n_channels: Number of coupled channels.
@@ -67,7 +66,7 @@ class RelativisticKMatrix(TMatrix):
             return_t_hat: Set to `True` if you want to get the
                 Lorentz-invariant :math:`\boldsymbol{\hat{T}}`-matrix instead
                 of the :math:`\boldsymbol{T}`-matrix from
-                Eq. :eq:`K-hat and T-hat`.
+                Eq. :eq:`K-hat-and-T-hat`.
         """
         return_t_hat: bool = kwargs.pop("return_t_hat", False)
         t_matrix, k_matrix = cls._create_matrices(n_channels, return_t_hat)
@@ -76,20 +75,20 @@ class RelativisticKMatrix(TMatrix):
         phsp_factor: PhaseSpaceFactorProtocol = kwargs.get(
             "phsp_factor", PhaseSpaceFactor
         )
-        s = sp.Symbol("s")
-        m_a = sp.IndexedBase("m_a")
-        m_b = sp.IndexedBase("m_b")
+        s = sp.Symbol("s", nonnegative=True)
+        m_a = sp.IndexedBase("m_a", nonnegative=True)
+        m_b = sp.IndexedBase("m_b", nonnegative=True)
         return t_matrix.xreplace(
             {
                 k_matrix[i, j]: cls.parametrization(
                     i=i,
                     j=j,
                     s=s,
-                    pole_position=sp.IndexedBase("m"),
-                    pole_width=sp.IndexedBase("Gamma"),
+                    pole_position=sp.IndexedBase("m", nonnegative=True),
+                    pole_width=sp.IndexedBase("Gamma", nonnegative=True),
                     m_a=m_a,
                     m_b=m_b,
-                    residue_constant=sp.IndexedBase("gamma"),
+                    residue_constant=sp.IndexedBase("gamma", nonnegative=True),
                     n_poles=n_poles,
                     pole_id=sp.Symbol("R", integer=True, positive=True),
                     angular_momentum=kwargs.get("angular_momentum", 0),
@@ -169,10 +168,10 @@ class NonRelativisticKMatrix(TMatrix):
                 k_matrix[i, j]: cls.parametrization(
                     i=i,
                     j=j,
-                    s=sp.Symbol("s"),
-                    pole_position=sp.IndexedBase("m"),
-                    pole_width=sp.IndexedBase("Gamma"),
-                    residue_constant=sp.IndexedBase("gamma"),
+                    s=sp.Symbol("s", nonnegative=True),
+                    pole_position=sp.IndexedBase("m", nonnegative=True),
+                    pole_width=sp.IndexedBase("Gamma", nonnegative=True),
+                    residue_constant=sp.IndexedBase("gamma", nonnegative=True),
                     n_poles=n_poles,
                     pole_id=sp.Symbol("R", integer=True, positive=True),
                 )
@@ -227,10 +226,10 @@ class NonRelativisticPVector(TMatrix):
         f_vector, k_matrix, p_vector = cls._create_matrices(n_channels)
         if not parametrize:
             return f_vector
-        s = sp.Symbol("s")
-        pole_position = sp.IndexedBase("m")
-        pole_width = sp.IndexedBase("Gamma")
-        residue_constant = sp.IndexedBase("gamma")
+        s = sp.Symbol("s", nonnegative=True)
+        pole_position = sp.IndexedBase("m", nonnegative=True)
+        pole_width = sp.IndexedBase("Gamma", nonnegative=True)
+        residue_constant = sp.IndexedBase("gamma", nonnegative=True)
         pole_id = sp.Symbol("R", integer=True, positive=True)
         return f_vector.xreplace(
             {
@@ -251,11 +250,11 @@ class NonRelativisticPVector(TMatrix):
             {
                 p_vector[i]: cls.parametrization(
                     i=i,
-                    s=sp.Symbol("s"),
+                    s=sp.Symbol("s", nonnegative=True),
                     pole_position=pole_position,
                     pole_width=pole_width,
                     residue_constant=residue_constant,
-                    beta_constant=sp.IndexedBase("beta"),
+                    beta_constant=sp.IndexedBase("beta", nonnegative=True),
                     n_poles=n_poles,
                     pole_id=pole_id,
                 )
@@ -308,7 +307,7 @@ class RelativisticPVector(TMatrix):
     def formulate(  # pylint: disable=too-many-locals
         cls, n_channels, n_poles, parametrize: bool = True, **kwargs
     ) -> sp.MutableDenseMatrix:
-        r"""Implementation of :eq:`F in terms of P`.
+        r"""Implementation of :eq:`F-in-terms-of-P`.
 
         Args:
             n_channels: Number of coupled channels.
@@ -319,7 +318,7 @@ class RelativisticPVector(TMatrix):
 
             return_f_hat: Set to `True` if you want to get the
                 Lorentz-invariant :math:`\hat{F}`-vector instead of the
-                :math:`T`-vector from Eq. :eq:`invariant vectors`.
+                :math:`T`-vector from Eq. :eq:`invariant-vectors`.
         """
         return_f_hat: bool = kwargs.pop("return_f_hat", False)
         f_vector, k_matrix, p_vector = cls._create_matrices(
@@ -330,12 +329,12 @@ class RelativisticPVector(TMatrix):
         phsp_factor: PhaseSpaceFactorProtocol = kwargs.get(
             "phsp_factor", PhaseSpaceFactor
         )
-        s = sp.Symbol("s")
-        pole_position = sp.IndexedBase("m")
-        pole_width = sp.IndexedBase("Gamma")
-        residue_constant = sp.IndexedBase("gamma")
-        m_a = sp.IndexedBase("m_a")
-        m_b = sp.IndexedBase("m_b")
+        s = sp.Symbol("s", nonnegative=True)
+        pole_position = sp.IndexedBase("m", nonnegative=True)
+        pole_width = sp.IndexedBase("Gamma", nonnegative=True)
+        residue_constant = sp.IndexedBase("gamma", nonnegative=True)
+        m_a = sp.IndexedBase("m_a", nonnegative=True)
+        m_b = sp.IndexedBase("m_b", nonnegative=True)
         pole_id = sp.Symbol("R", integer=True, positive=True)
         angular_momentum = kwargs.get("angular_momentum", 0)
         meson_radius = kwargs.get("meson_radius", 1)
@@ -369,7 +368,7 @@ class RelativisticPVector(TMatrix):
                         pole_width=pole_width,
                         m_a=m_a,
                         m_b=m_b,
-                        beta_constant=sp.IndexedBase("beta"),
+                        beta_constant=sp.IndexedBase("beta", nonnegative=True),
                         residue_constant=residue_constant,
                         n_poles=n_poles,
                         pole_id=pole_id,
@@ -406,11 +405,9 @@ class RelativisticPVector(TMatrix):
         gamma = residue_constant[pole_id, i]
         mass0 = pole_position[pole_id]
         width = pole_width[pole_id, i]
-        q_squared = BreakupMomentumSquared(s, m_a[i], m_b[i])
-        form_factor_squared = BlattWeisskopfSquared(
-            angular_momentum, z=q_squared * meson_radius**2
+        form_factor = formulate_form_factor(
+            s, m_a[i], m_b[i], angular_momentum, meson_radius
         )
-        form_factor = sp.sqrt(form_factor_squared)
         return sp.Sum(
             beta * gamma * mass0 * width * form_factor / (mass0**2 - s),
             (pole_id, 1, n_poles),
