@@ -47,12 +47,11 @@ from ampform.dynamics.builder import (
     TwoBodyKinematicVariableSet,
     create_non_dynamic,
 )
-from ampform.kinematics import HelicityAdapter, get_invariant_mass_label
+from ampform.kinematics import HelicityAdapter, get_invariant_mass_symbol
 from ampform.sympy import PoolSum
 
 from .decay import (
     TwoBodyDecay,
-    collect_topologies,
     get_parent_id,
     get_prefactor,
     get_sibling_state_id,
@@ -65,7 +64,7 @@ from .naming import (
     HelicityAmplitudeNameGenerator,
     NameGenerator,
     generate_transition_label,
-    get_helicity_angle_label,
+    get_helicity_angle_symbols,
     get_helicity_suffix,
     get_topology_identifier,
     natural_sorting,
@@ -233,7 +232,7 @@ class HelicityModel:  # noqa: R701
         symbols: set[sp.Symbol] = self.expression.free_symbols  # type: ignore[assignment]
         symbols |= set(self.kinematic_variables)
         for expr in self.kinematic_variables.values():
-            symbols |= expr.free_symbols  # type: ignore[misc]
+            symbols |= expr.free_symbols  # type: ignore[arg-type]
         return symbols
 
     def sum_components(  # noqa: R701
@@ -256,8 +255,8 @@ class HelicityModel:  # noqa: R701
                     "Did you mean any of these?",
                     candidates,
                 )
-        if any(map(lambda c: c.startswith("I"), components)) and any(
-            map(lambda c: c.startswith("A"), components)
+        if any(c.startswith("I") for c in components) and any(
+            c.startswith("A") for c in components
         ):
             intensity_sum = self.sum_components(
                 components=filter(lambda c: c.startswith("I"), components),
@@ -266,9 +265,9 @@ class HelicityModel:  # noqa: R701
                 components=filter(lambda c: c.startswith("A"), components),
             )
             return intensity_sum + amplitude_sum
-        if all(map(lambda c: c.startswith("I"), components)):
+        if all(c.startswith("I") for c in components):
             return sum(self.components[c] for c in components)  # type: ignore[return-value]
-        if all(map(lambda c: c.startswith("A"), components)):
+        if all(c.startswith("A") for c in components):
             return abs(sum(self.components[c] for c in components)) ** 2
         raise ValueError(
             'Not all component names started with either "A" or "I"'
@@ -518,7 +517,7 @@ class HelicityAmplitudeBuilder:  # pylint: disable=too-many-instance-attributes
         self.__ingredients = _HelicityModelIngredients()
         self.__dynamics_choices = DynamicsSelector(reaction)
         self.__adapter = HelicityAdapter(reaction)
-        self.align_spin: bool | None = None
+        self.align_spin: bool = False
         """(De)activate :doc:`spin alignment </usage/helicity/spin-alignment>`."""
         self.use_helicity_couplings: bool = False
         """Use helicity couplings instead of amplitude coefficients.
@@ -586,22 +585,18 @@ class HelicityAmplitudeBuilder:  # pylint: disable=too-many-instance-attributes
     def formulate(self) -> HelicityModel:
         self.__ingredients.reset()
         main_intensity = self.__formulate_top_expression()
-        _str_kinematic_variables = self.__adapter.create_expressions(
-            generate_wigner_angles=self.__is_align_spin
+        kinematic_variables = self.__adapter.create_expressions(
+            generate_wigner_angles=self.align_spin
         )
-        kinematic_variables = {
-            sp.Symbol(var_name, real=True): expr
-            for var_name, expr in _str_kinematic_variables.items()
-        }
         if self.stable_final_state_ids is not None:
             for state_id in self.stable_final_state_ids:
-                symbol = sp.Symbol(f"m_{state_id}", real=True)
+                symbol = sp.Symbol(f"m_{state_id}", nonnegative=True)
                 particle = self.__reaction.final_state[state_id]
                 self.__ingredients.parameter_defaults[symbol] = particle.mass
                 del kinematic_variables[symbol]
         if self.scalar_initial_state_mass:
             subscript = "".join(map(str, sorted(self.__reaction.final_state)))
-            symbol = sp.Symbol(f"m_{subscript}", real=True)
+            symbol = sp.Symbol(f"m_{subscript}", nonnegative=True)
             particle = self.__reaction.initial_state[-1]
             self.__ingredients.parameter_defaults[symbol] = particle.mass
             del kinematic_variables[symbol]
@@ -632,7 +627,7 @@ class HelicityAmplitudeBuilder:  # pylint: disable=too-many-instance-attributes
                     spin_projections[symbol].add(value)
 
         topology_groups = group_by_topology(self.__reaction.transitions)
-        if self.__is_align_spin:
+        if self.align_spin:
             amplitude = self.__formulate_aligned_amplitude(topology_groups)
         else:
             indices = list(spin_projections)
@@ -663,13 +658,6 @@ class HelicityAmplitudeBuilder:  # pylint: disable=too-many-instance-attributes
             )
         return amplitude
 
-    @property
-    def __is_align_spin(self) -> bool:
-        if self.align_spin is None:
-            topologies = collect_topologies(self.__reaction.transitions)
-            return len(topologies) > 1
-        return self.align_spin
-
     def __register_amplitudes(
         self, transition_group: list[StateTransition]
     ) -> None:
@@ -1006,7 +994,7 @@ def formulate_wigner_d(transition: StateTransition, node_id: int) -> sp.Expr:
       `~qrules.transition.State.spin_projection` when following a constistent
       boosting procedure),
     - and :math:`\phi` and :math:`\theta` the helicity angles (see also
-      :func:`.get_helicity_angle_label`).
+      :func:`.get_helicity_angle_symbols`).
 
     Note that :math:`\lambda_2, \lambda_3` are ordered by their number of
     children, then by their state ID (see :class:`.TwoBodyDecay`).
@@ -1131,9 +1119,7 @@ def formulate_helicity_rotation_chain(
         idx_root_counter += 1
         if is_opposite_helicity_state(topology, state_id):
             state_id = get_sibling_state_id(topology, state_id)
-        phi_label, theta_theta = get_helicity_angle_label(topology, state_id)
-        phi = sp.Symbol(phi_label, real=True)
-        theta = sp.Symbol(theta_theta, real=True)
+        phi, theta = get_helicity_angle_symbols(topology, state_id)
         no_zero_spin = transition.states[rotated_state_id].particle.mass == 0.0
         yield formulate_helicity_rotation(
             spin_magnitude,
@@ -1281,7 +1267,9 @@ def formulate_helicity_rotation(
     )
 
 
-_BasicType = TypeVar("_BasicType", bound=sp.Basic)
+_BasicType = TypeVar(  # pylint: disable=invalid-name
+    "_BasicType", bound=sp.Basic
+)
 
 
 @overload
@@ -1332,14 +1320,9 @@ def _generate_kinematic_variable_set(
 ) -> TwoBodyKinematicVariableSet:
     decay = TwoBodyDecay.from_transition(transition, node_id)
     inv_mass, phi, theta = _generate_kinematic_variables(transition, node_id)
-    child1_mass = sp.Symbol(
-        get_invariant_mass_label(transition.topology, decay.children[0].id),
-        real=True,
-    )
-    child2_mass = sp.Symbol(
-        get_invariant_mass_label(transition.topology, decay.children[1].id),
-        real=True,
-    )
+    topology = transition.topology
+    child1_mass = get_invariant_mass_symbol(topology, decay.children[0].id)
+    child2_mass = get_invariant_mass_symbol(topology, decay.children[1].id)
     angular_momentum: int | None = decay.interaction.l_magnitude
     if angular_momentum is None:
         if decay.parent.particle.spin.is_integer():
@@ -1359,14 +1342,7 @@ def _generate_kinematic_variables(
 ) -> tuple[sp.Symbol, sp.Symbol, sp.Symbol]:
     """Generate symbol for invariant mass, phi angle, and theta angle."""
     decay = TwoBodyDecay.from_transition(transition, node_id)
-    phi_label, theta_label = get_helicity_angle_label(
-        transition.topology, decay.children[0].id
-    )
-    inv_mass_label = get_invariant_mass_label(
-        transition.topology, decay.parent.id
-    )
-    return (
-        sp.Symbol(inv_mass_label, real=True),
-        sp.Symbol(phi_label, real=True),
-        sp.Symbol(theta_label, real=True),
-    )
+    topology = transition.topology
+    phi, theta = get_helicity_angle_symbols(topology, decay.children[0].id)
+    invariant_mass = get_invariant_mass_symbol(topology, decay.parent.id)
+    return invariant_mass, phi, theta
