@@ -39,7 +39,7 @@ class TwoBodyDecay:
        1-to-2 body decay
 
     2. its two `.children` are sorted by whether they decay further or not (see
-       `.get_helicity_angle_label`, `.formulate_wigner_d`, and
+       `.get_helicity_angle_symbols`, `.formulate_wigner_d`, and
        `.formulate_clebsch_gordan_coefficients`).
 
     3. the `.TwoBodyDecay` is hashable, so that it can be used as a key (see
@@ -147,13 +147,6 @@ def is_opposite_helicity_state(topology: Topology, state_id: int) -> bool:
     return tuple(state_fs_ids) > tuple(sibling_fs_ids)
 
 
-@lru_cache(maxsize=None)
-def collect_topologies(
-    transitions: tuple[StateTransition, ...]
-) -> list[Topology]:
-    return sorted({t.topology for t in transitions})
-
-
 def get_sibling_state_id(topology: Topology, state_id: int) -> int:
     r"""Get the sibling state ID for a state in an isobar decay.
 
