@@ -1,4 +1,6 @@
 # pylint: disable=no-self-use, protected-access
+from __future__ import annotations
+
 import re
 
 import pytest
@@ -40,8 +42,9 @@ class TestNonRelativisticKMatrix:
 
 
 def _remove_residue_constants(expression: sp.Expr) -> sp.Expr:
+    free_symbols: set[sp.Symbol] = expression.free_symbols  # type: ignore[assignment]
     residue_constants = filter(
-        lambda s: s.name.startswith(R"\gamma_"), expression.free_symbols
+        lambda s: s.name.startswith(R"\gamma_"), free_symbols
     )
     return expression.xreplace({gamma: 1 for gamma in residue_constants})
 
